import _extends from "@babel/runtime/helpers/esm/extends";
import { useEffect, useRef, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import Handler from './Handler.js';
import markerFactory from './markerFactory.js';
import { BASE_CLASS, CLASS_DISABLED, CLASS_FULLWIDTH, CLASS_INVERSE, Label, Range, Slider } from './settings.js';
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
var getHandle = function getHandle(_ref) {
  var refAtomSlider = _ref.refAtomSlider,
    hideTooltip = _ref.hideTooltip;
  return function (props) {
    return /*#__PURE__*/_jsx(Handler, _extends({
      refAtomSlider: refAtomSlider,
      hideTooltip: hideTooltip
    }, props));
  };
};
var AtomSlider = function AtomSlider(_ref2) {
  var _cx, _cx2, _cx3;
  var onChange = _ref2.onChange,
    onAfterChange = _ref2.onAfterChange,
    value = _ref2.value,
    _ref2$min = _ref2.min,
    min = _ref2$min === void 0 ? 0 : _ref2$min,
    _ref2$max = _ref2.max,
    max = _ref2$max === void 0 ? 100 : _ref2$max,
    _ref2$step = _ref2.step,
    step = _ref2$step === void 0 ? 1 : _ref2$step,
    range = _ref2.range,
    disabled = _ref2.disabled,
    valueLabel = _ref2.valueLabel,
    marks = _ref2.marks,
    valueLabelFormatter = _ref2.valueLabelFormatter,
    _ref2$hideMarks = _ref2.hideMarks,
    hideMarks = _ref2$hideMarks === void 0 ? false : _ref2$hideMarks,
    _ref2$hideTooltip = _ref2.hideTooltip,
    hideTooltip = _ref2$hideTooltip === void 0 ? false : _ref2$hideTooltip,
    defaultValue = _ref2.defaultValue,
    invertColors = _ref2.invertColors,
    isFullWidth = _ref2.isFullWidth;
  var initialStateValue;
  var refAtomSlider = useRef();
  var numMax = Number(max);
  var numMin = Number(min);
  if (value !== undefined) {
    initialStateValue = range ? value.map(Number) : Number(value);
  } else if (defaultValue !== undefined) {
    initialStateValue = range ? defaultValue.map(Number) : Number(defaultValue);
  } else {
    initialStateValue = range ? [numMin, numMax] : Math.trunc((numMin + numMax - numMin) / 2);
  }
  var _useState = useState(initialStateValue),
    internalValue = _useState[0],
    setInternalValue = _useState[1];
  useEffect(function () {
    if (value !== undefined) {
      setInternalValue(range ? value.map(Number) : Number(value));
    }
  }, [value, range]);
  var handleChange = function handleChange(newValue) {
    var e = {};
    if (value === undefined) {
      setInternalValue(newValue);
    }
    if (typeof onChange === 'function') {
      onChange(e, {
        value: newValue
      });
    }
  };
  var handleAfterChange = function handleAfterChange(value) {
    if (typeof onAfterChange === 'function') {
      onAfterChange({}, {
        value: value
      });
    }
  };
  var customProps = {
    handle: getHandle({
      refAtomSlider: refAtomSlider,
      hideTooltip: hideTooltip
    }),
    onChange: handleChange,
    onAfterChange: handleAfterChange,
    disabled: disabled,
    marks: hideMarks ? {} : markerFactory({
      step: step,
      min: min,
      max: max,
      marks: marks,
      isFullWidth: isFullWidth
    }),
    max: max,
    min: min,
    step: step,
    value: internalValue
  };
  var computedClassName = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_DISABLED] = disabled, _cx), (_cx2 = {}, _cx2[CLASS_INVERSE] = invertColors, _cx2), (_cx3 = {}, _cx3[CLASS_FULLWIDTH] = isFullWidth, _cx3));

  // Determine the type of the slider according to the range prop
  var Type = range ? Range : Slider;
  return /*#__PURE__*/_jsx("div", {
    ref: refAtomSlider,
    className: computedClassName,
    children: valueLabel && customProps.handle ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Label, {
        value: internalValue.toString(),
        formatter: valueLabelFormatter,
        percentage: (internalValue - min) / (max - min) * 100
      }), /*#__PURE__*/_jsx(Type, _extends({}, customProps))]
    }) : /*#__PURE__*/_jsx(Type, _extends({}, customProps))
  });
};
AtomSlider.displayName = 'AtomSlider';
export default AtomSlider;